<!-- markdownlint-disable MD031 MD033 MD036 MD041 -->

<div align="center">

_Logo 征集中 / Logo currently soliciting opinion_

# CooAki

_✨ Another Async Akinator API Wrapper ✨_

<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">
<a href="https://pdm.fming.dev">
  <img src="https://img.shields.io/badge/pdm-managed-blueviolet" alt="pdm-managed">
</a>
<a href="https://wakatime.com/badge/user/b61b0f9a-f40b-4c82-bc51-0a75c67bfccf/project/f33b1b73-7e24-494b-945b-501cf458dc19">
  <img src="https://wakatime.com/badge/user/b61b0f9a-f40b-4c82-bc51-0a75c67bfccf/project/f33b1b73-7e24-494b-945b-501cf458dc19.svg" alt="wakatime">
</a>

<br />

<a href="./LICENSE">
  <img src="https://img.shields.io/github/license/lgc2333/cooaki.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/cooaki">
  <img src="https://img.shields.io/pypi/v/cooaki.svg" alt="pypi">
</a>
<a href="https://pypi.python.org/pypi/cooaki">
  <img src="https://img.shields.io/pypi/dm/cooaki" alt="pypi download">
</a>

</div>

## 💿 安装 / Install

```shell
pip install cooaki
```

## 📖 介绍 / Description

参见 [cooaki/\_\_main\_\_.py](https://github.com/lgc2333/cooaki/blob/master/cooaki/__main__.py)  
Please refer to [cooaki/\_\_main\_\_.py](https://github.com/lgc2333/cooaki/blob/master/cooaki/__main__.py)

安装好后可以用 `python -m cooaki` 来运行这个 Demo  
You can run this demo using `python -m cooaki` when this package was installed.

## 📞 联系 / Contact Me

- QQ: 3076823485 / Group: [1105946125](https://jq.qq.com/?_wv=1027&k=Z3n1MpEp)
- Telegram: [@lgc2333](https://t.me/lgc2333) / [@stupmbot](https://t.me/stupmbot)
- Discord: [lgc2333](https://discordapp.com/users/810486152401256448)
- Email: [lgc2333@126.com](mailto:lgc2333@126.com)

## 💡 鸣谢 / Acknowledgments

### [advnpzn/akipy](https://github.com/advnpzn/akipy)

- API 参考 / API References

## 💰 赞助 / Sponsor Me

**[点击这里获取更多信息  
Click here for more information](https://blog.lgc2333.top/donate)**

感谢大家的赞助！你们的赞助将是我继续创作的动力！  
Thanks for your support! Your support will make me continue to create contents!

## 📝 更新日志 / Update Log

芝士刚刚发布的插件，还没有更新日志的说 qwq~
